@@ -27,8 +27,25 @@ create_changelog >"$ext_dir/CHANGELOG.md"
 
    # Delete debug info
    rm -rf -v {arm,arm64,x64}/{linux,darwin,win32}/*.{debug,dSYM}
+
+   # Determine if this is a pre-release. The convention is based on the last
+   # digit of the version:
+   #  0 --> pre-release
+   #  1 -->     release
+   #  2 --> pre-release (based on edge branch)
+   #  3 -->     release (based on edge branch)
+   case "$TAG" in
+   *1 | *3)
+      pre_release=""
+      ;;
+   *)
+      # default to a pre-release
+      pre_release=--pre-release
+      ;;
+   esac
+
    # Create the VSIX
-   npx vsce package --target "${NODE_PLATFORM}-${NODE_ARCH}"
+   npx vsce package --target "${NODE_PLATFORM}-${NODE_ARCH}" $pre_release
 )
 
 # Move all .vsix packages to the root of the checkout
